@@ -1,4 +1,4 @@
-/* --< GKrellAclock 0.3.3 >--{ 22 Jan 2005 }--
+/* --< GKrellAclock 0.3.4 >--{ 15 Aug 2006 }--
  * Ported to GkrellM2.0
  * includes Bill Nalen's windows port.
  *
@@ -27,7 +27,7 @@
 
 #include<math.h>
 
-#define GKRELLACLOCK_VER 	"0.3.3"
+#define GKRELLACLOCK_VER 	"0.3.4"
 
 #define	CONFIG_NAME	"GkrellAclock"	/* Name in the configuration window */
 #define	STYLE_NAME	"GkrellAclock"	/* Theme subdirectory name */
@@ -36,7 +36,8 @@
 
 #define CHART_W 60
 #define CHART_H 40
-#define MAX_COLORS 8
+#define MAX_COLORS 10
+#define MAX_DARK_BG_COLORS 8
 
 #define WHITE  0
 #define ORANGE 1
@@ -46,6 +47,8 @@
 #define RED    5
 #define GRAY   6
 #define L_PINK 7
+#define BROWN  8
+#define BLACK  9
 
 #define N_WHITE  "White"
 #define N_ORANGE "Orange"
@@ -64,6 +67,7 @@ static GkrellmChart		*chart;
 static GkrellmChartconfig	*chart_config=NULL;
 
 static GtkWidget	*cycle_option,
+			*bg_option,
 			*sec_select_option,
 			*dial_select_option,
 			*clock_type_option[2];
@@ -73,7 +77,7 @@ static gchar	*color_name[] = { N_WHITE, N_ORANGE, N_GREEN, N_YELLOW,
 
 static gint c_red[MAX_COLORS], c_green[MAX_COLORS], c_blue[MAX_COLORS];
 
-static gint d_color, s_color, cycle, clock_type;
+static gint d_color, s_color, cycle, clock_type, enable_dark_bg;
 static gint prev_h = -1;
 static gint chart_w = 60;
 
@@ -81,9 +85,9 @@ static gint		style_id;
 
 struct tm  *tm;
 
-static gint r_value[] = { 255, 255, 0  , 255, 51 , 255, 214, 255 };
-static gint g_value[] = { 255, 165, 255, 255, 255, 0  , 214, 204 };
-static gint b_value[] = { 255, 0  , 0  , 102, 255, 0  , 214, 255 };
+static gint r_value[] = { 255, 255, 0  , 255, 51 , 255, 214, 255, 255, 3 };
+static gint g_value[] = { 255, 165, 255, 255, 255, 0  , 214, 204, 48 , 3};
+static gint b_value[] = { 255, 0  , 0  , 102, 255, 0  , 214, 255, 48 , 3};
 
 guchar *rgbbuf;
 
@@ -116,7 +120,11 @@ blank_buf(void)
       for (x = 0; x < chart_w; x++)
         {
 
-          pos[0] = pos[1] = pos[2] = 0;
+          if ( enable_dark_bg ) { pos[0] = pos[1] = pos[2] = 0; }
+          else { pos[0] = pos[1] = pos[2] = 245; 
+                 d_color = BLACK;
+                 s_color = BROWN;
+          }
           pos += 3;
         }
     }
@@ -507,8 +515,13 @@ lineBresenham(gint x0, gint y0, gint x1, gint y1, guchar b,
 static void
 change_dial_color(void)
 {
-   d_color++;
-   if ( d_color >= MAX_COLORS ) { d_color = 0; }
+   if ( enable_dark_bg ) {
+      d_color++;
+      if ( d_color >= MAX_DARK_BG_COLORS ) { d_color = 0; }
+   } else { d_color = BLACK; 
+            s_color = BROWN;
+     }
+
 }
 
 static void
@@ -697,13 +710,12 @@ chart_expose_event(GtkWidget *widget, GdkEventExpose *ev)
 }
 
 static void
-update_plugin ()
+update_plugin ( void )
 {
   GdkEventExpose event;
   gint ret_val;
 
-  gtk_signal_emit_by_name(GTK_OBJECT(chart->drawing_area),
-                                "expose_event", &event, &ret_val  );
+  g_signal_emit_by_name(GTK_OBJECT(chart->drawing_area), "expose_event", &event, &ret_val  );
 }
 
 static gint
@@ -718,7 +730,7 @@ chart_press (GtkWidget *widget, GdkEventButton *ev)
     if (ev->button == 2 )
     {
 	   s_color++;
-	   if ( s_color >= MAX_COLORS ) { s_color = 0; }
+	   if ( s_color >= MAX_DARK_BG_COLORS ) { s_color = 0; }
 
        draw_clock();
     }
@@ -771,11 +783,11 @@ create_plugin(GtkWidget *vbox, gint first_create)
 
 	if (first_create)
 	{	
-	    gtk_signal_connect(GTK_OBJECT (chart->drawing_area), "expose_event",
-    	        (GtkSignalFunc) chart_expose_event, NULL);
+	    g_signal_connect(GTK_OBJECT (chart->drawing_area), "expose_event",
+    	        G_CALLBACK ( chart_expose_event ), NULL);
 
-	    gtk_signal_connect(GTK_OBJECT(chart->drawing_area),
-            "button_press_event", (GtkSignalFunc) chart_press, NULL);
+	    g_signal_connect(GTK_OBJECT(chart->drawing_area),
+            "button_press_event", G_CALLBACK ( chart_press ), NULL);
 
 
 	    gdk_rgb_init();
@@ -790,14 +802,11 @@ create_plugin(GtkWidget *vbox, gint first_create)
 static void
 save_aclock_config (FILE *f)
 {
-    fprintf(f, "%s cycle %d\n", PLUGIN_CONFIG_KEYWORD,
-            cycle);
-    fprintf(f, "%s d_color %d\n", PLUGIN_CONFIG_KEYWORD,
-            d_color);
-    fprintf(f, "%s s_color %d\n", PLUGIN_CONFIG_KEYWORD,
-            s_color);
-    fprintf(f, "%s clock_type %d\n", PLUGIN_CONFIG_KEYWORD,
-            clock_type);
+    fprintf(f, "%s cycle %d\n", PLUGIN_CONFIG_KEYWORD, cycle);
+    fprintf(f, "%s d_color %d\n", PLUGIN_CONFIG_KEYWORD, d_color);
+    fprintf(f, "%s s_color %d\n", PLUGIN_CONFIG_KEYWORD, s_color);
+    fprintf(f, "%s clock_type %d\n", PLUGIN_CONFIG_KEYWORD, clock_type);
+    fprintf(f, "%s enable_dark_bg %d\n", PLUGIN_CONFIG_KEYWORD, enable_dark_bg);
 }
 
 static void
@@ -817,6 +826,8 @@ load_aclock_config (gchar *arg)
             sscanf(item, "%d\n", &(s_color));
         if (strcmp(config, "clock_type") == 0)
             sscanf(item, "%d\n", &(clock_type));
+        if (strcmp(config, "enable_dark_bg") == 0)
+            sscanf(item, "%d\n", &(enable_dark_bg));
     }
 
 }
@@ -848,6 +859,8 @@ apply_aclock_config (void)
     c = gkrellm_gtk_entry_get_text(&(GTK_COMBO(sec_select_option)->entry));
 	s_color = get_color_from_name( c );
 
+    enable_dark_bg = GTK_TOGGLE_BUTTON(bg_option)->active;
+
 }
 
 
@@ -857,6 +870,19 @@ static void cycle_clicked(GtkButton* button )
     cycle = GTK_TOGGLE_BUTTON(cycle_option)->active;
 }
 
+static void cb_enable_dark_bg(GtkButton* button, GtkWidget *box )
+{
+    enable_dark_bg = GTK_TOGGLE_BUTTON(bg_option)->active;
+
+    gtk_widget_set_sensitive(box, enable_dark_bg);
+    if ( enable_dark_bg ) {
+       d_color = WHITE;
+       s_color = RED;
+       gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(dial_select_option)->entry), color_name[d_color] );
+       gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(sec_select_option)->entry), color_name[s_color] );
+    }
+}
+
 static void
 cb_clock_type(GtkWidget *button, gpointer data)
 {
@@ -867,10 +893,10 @@ cb_clock_type(GtkWidget *button, gpointer data)
 }
 
 static void
-create_aclock_tab (GtkWidget *tab)
+create_aclock_tab (GtkWidget *tab_vbox)
 {
-    GtkWidget *laptop, *about_label, *label, *frame, *hbox, *vbox, *ybox;
-	GtkWidget *s_label, *text, *info_window, *button ;
+    GtkWidget *tabs, *about_label, *label, *frame, *hbox, *vbox, *ybox, *vbox1, *vbox2;
+	GtkWidget *s_label, *text, *button ;
 
 	GList *d_items = NULL;
 	GList *s_items = NULL;
@@ -880,21 +906,22 @@ create_aclock_tab (GtkWidget *tab)
     gint i;
 	static gchar *help_text[] =
     {
-      "<b>" CONFIG_NAME " " GKRELLACLOCK_VER "\n\n" ,
-      "Simple Analog Clock \n\n" ,
-      "Left-click will change dial color, Middle-click will change seconds color\n",
-      "and right-click opens configuration windws.\n\n",
-      "<b> Options \n\n" ,
-      "Cycle Dial Color - when checked will change dial color every hour.\n\n",
-      "Clock Type - choose from Aclock and Xclock type .\n\n",
-      "Select Dial Color  from drop down .\n",
-      "Select Seconds Color from drop down .\n",
+      N_("<h>" CONFIG_NAME " " GKRELLACLOCK_VER "\n\n" ),
+      N_("<b>Simple Analog Clock \n\n" ),
+      N_("Left-click will change dial color and Middle-click will change seconds \n" ),
+      N_("color when Dark background is enabled.\n\n"),
+      N_("Right-click opens configuration window.\n\n"),
+      N_("<b> Options \n\n" ),
+      N_("Clock Type - choose from Aclock and Xclock type .\n\n" ),
+      N_("Enable Dark Background - toggles between dark and light background .\n\n" ),
+      N_("Cycle Dial Color - when checked will change dial color every hour.\n\n" ),
+      N_("Select Dial Color  from drop down .\n" ),
+      N_("Select Seconds Color from drop down .\n" )
     };
 
-
-    laptop = gtk_notebook_new();
-    gtk_notebook_set_tab_pos(GTK_NOTEBOOK(laptop), GTK_POS_TOP);
-    gtk_box_pack_start(GTK_BOX(tab), laptop, TRUE, TRUE, 0);
+    tabs = gtk_notebook_new();
+    gtk_notebook_set_tab_pos(GTK_NOTEBOOK(tabs), GTK_POS_TOP);
+    gtk_box_pack_start(GTK_BOX(tab_vbox), tabs, TRUE, TRUE, 0);
 
 	/* Options */
 	frame = gtk_frame_new(NULL);
@@ -903,19 +930,6 @@ create_aclock_tab (GtkWidget *tab)
     vbox = gtk_vbox_new( FALSE, 0 );
     gtk_container_border_width(GTK_CONTAINER(vbox), 3);
 
-
-	/* Cycle Dial Color */
-
-
-    cycle_option = gtk_check_button_new_with_label( "Cycle Dial Color" );
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cycle_option),
-            cycle );
-
-    gtk_signal_connect(GTK_OBJECT(cycle_option), "clicked",
-                GTK_SIGNAL_FUNC(cycle_clicked), NULL );
-
-    gtk_box_pack_start(GTK_BOX(vbox), cycle_option, FALSE, FALSE, 0);
-
     /* Clock Type */
     
      ybox = gkrellm_gtk_framed_vbox(vbox, _("Clock Type"),
@@ -938,12 +952,35 @@ create_aclock_tab (GtkWidget *tab)
                                         G_CALLBACK(cb_clock_type), GINT_TO_POINTER(i));
      }      
 
+	/* Enable Dark Background */
+
+
+    vbox2 = gtk_vbox_new( FALSE, 0 );
+    gtk_container_border_width(GTK_CONTAINER(vbox2), 3);
+
+    bg_option = gtk_check_button_new_with_label( "Enable Dark Background " );
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(bg_option), enable_dark_bg );
+
+	gtk_widget_set_sensitive(vbox2, enable_dark_bg ? TRUE : FALSE );
+    g_signal_connect(GTK_OBJECT(bg_option), "clicked", G_CALLBACK(cb_enable_dark_bg), vbox2 );
+
+    gtk_box_pack_start(GTK_BOX(vbox), bg_option, FALSE, FALSE, 0);
+
+	/* Cycle Dial Color */
+
+    cycle_option = gtk_check_button_new_with_label( "Cycle Dial Color" );
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cycle_option),
+            cycle );
+
+    g_signal_connect(GTK_OBJECT(cycle_option), "clicked", G_CALLBACK(cycle_clicked), NULL );
+
+    gtk_box_pack_start(GTK_BOX(vbox2), cycle_option, FALSE, FALSE, 0);
 
 	/* Dial Color */
     hbox = gtk_hbox_new(FALSE, 0);
     label = gtk_label_new("Dial Color " );
 
-    for ( i = 0; i < MAX_COLORS; i++ )
+    for ( i = 0; i < MAX_DARK_BG_COLORS; i++ )
     {
       d_items = g_list_append (d_items, color_name[i] );
     }
@@ -951,13 +988,16 @@ create_aclock_tab (GtkWidget *tab)
     dial_select_option = gtk_combo_new();
     gtk_combo_set_popdown_strings (GTK_COMBO (dial_select_option), d_items);
     gtk_combo_set_value_in_list( GTK_COMBO(dial_select_option), TRUE, FALSE );
-    gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(dial_select_option)->entry),
-                                                color_name[d_color] );
+    if ( enable_dark_bg ) {
+       gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(dial_select_option)->entry), color_name[d_color] );
+    } else {
+       gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(dial_select_option)->entry), color_name[WHITE] );
+    }
 
     gtk_box_pack_end(GTK_BOX(hbox), dial_select_option, FALSE, FALSE, 0);
     gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
-    gtk_container_add(GTK_CONTAINER(vbox), hbox);
+    gtk_container_add(GTK_CONTAINER(vbox2), hbox);
 
 	/* Seconds Color */
 
@@ -965,7 +1005,7 @@ create_aclock_tab (GtkWidget *tab)
 
     s_label = gtk_label_new("Seconds Color " );
 
-    for ( i = 0; i < MAX_COLORS; i++ )
+    for ( i = 0; i < MAX_DARK_BG_COLORS; i++ )
     {
       s_items = g_list_append (s_items, color_name[i] );
     }
@@ -973,41 +1013,35 @@ create_aclock_tab (GtkWidget *tab)
     sec_select_option = gtk_combo_new();
     gtk_combo_set_popdown_strings (GTK_COMBO (sec_select_option), s_items);
     gtk_combo_set_value_in_list( GTK_COMBO(sec_select_option), TRUE, FALSE );
-    gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(sec_select_option)->entry),
-                                                color_name[s_color] );
+    if ( enable_dark_bg ) {
+       gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(sec_select_option)->entry), color_name[s_color] );
+    } else {
+       gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(sec_select_option)->entry), color_name[RED] );
+    }
 
     gtk_box_pack_end(GTK_BOX(hbox), sec_select_option, FALSE, FALSE, 0);
     gtk_box_pack_end(GTK_BOX(hbox), s_label, FALSE, FALSE, 0);
 
-    gtk_container_add(GTK_CONTAINER(vbox), hbox);
+    gtk_container_add(GTK_CONTAINER(vbox2), hbox);
+    gtk_container_add(GTK_CONTAINER(vbox), vbox2);
 
     label = gtk_label_new("Options");
     gtk_container_add(GTK_CONTAINER(frame), vbox);
-    gtk_notebook_append_page(GTK_NOTEBOOK(laptop), frame, label);
+    gtk_notebook_append_page(GTK_NOTEBOOK(tabs), frame, label);
 
         /* help */
-    frame = gtk_frame_new(NULL);
-    gtk_container_border_width(GTK_CONTAINER(frame), 3);
-    info_window = gtk_scrolled_window_new(NULL, NULL);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(info_window),
-    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-    gtk_container_add(GTK_CONTAINER(frame), info_window);
-
-    text = gtk_text_view_new();
-
-    gkrellm_gtk_text_view_append_strings(text, help_text, sizeof(help_text)/sizeof(gchar*));
-    gtk_text_view_set_editable(GTK_TEXT_VIEW(text), FALSE);
-    gtk_container_add(GTK_CONTAINER(info_window), text);
-
-    label = gtk_label_new("Help");
-    gtk_notebook_append_page(GTK_NOTEBOOK(laptop), frame, label);
+	vbox1 = gkrellm_gtk_framed_notebook_page(tabs, _("Help"));
+	text = gkrellm_gtk_scrolled_text_view(vbox1, NULL,
+				GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	for (i = 0; i < sizeof(help_text)/sizeof(gchar *); ++i)
+		gkrellm_gtk_text_view_append(text, _(help_text[i]));
 
         /* about */
     about_text = g_strdup_printf(
         "GKrellAclock %s\n" \
         "GKrellM Aclock Plugin\n" \
         "\n" \
-        "Copyright (C) 2005 M.R.Muthu Kumar\n" \
+        "Copyright (C) 2006 M.R.Muthu Kumar\n" \
         "m_muthukumar@users.sourceforge.net\n" \
         "\n" \
         "Released under the GNU Public License\n" \
@@ -1017,7 +1051,7 @@ create_aclock_tab (GtkWidget *tab)
     about_label = gtk_label_new(about_text);
     g_free(about_text);
     label = gtk_label_new("About");
-    gtk_notebook_append_page(GTK_NOTEBOOK(laptop), about_label, label);
+    gtk_notebook_append_page(GTK_NOTEBOOK(tabs), about_label, label);
 }
 
 
@@ -1051,7 +1085,7 @@ __declspec(dllexport) GkrellmMonitor *
 gkrellm_init_plugin(win32_plugin_callbacks* calls)
 #else
 GkrellmMonitor *
-gkrellm_init_plugin()
+gkrellm_init_plugin( void )
 #endif
 	{
       gint i;
@@ -1076,6 +1110,7 @@ gkrellm_init_plugin()
 	s_color = RED;
 	cycle   = 1;
         clock_type = X_CLOCK;
+        enable_dark_bg = FALSE;
 
 
 	chart_w = gkrellm_chart_width();
